@@ -2,12 +2,17 @@ package Test2::Harness::UI::Controller::JobField;
 use strict;
 use warnings;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000076';
 
+use Data::GUID;
+use List::Util qw/max/;
+use Text::Xslate(qw/mark_raw/);
+use Test2::Harness::UI::Util qw/share_dir/;
 use Test2::Harness::UI::Response qw/resp error/;
+use Test2::Harness::Util::JSON qw/encode_json decode_json/;
 
 use parent 'Test2::Harness::UI::Controller';
-use Test2::Harness::UI::Util::HashBase;
+use Test2::Harness::UI::Util::HashBase qw/-title/;
 
 sub handle {
     my $self = shift;
@@ -15,13 +20,21 @@ sub handle {
 
     my $req = $self->{+REQUEST};
 
+    my $res = resp(200);
+    my $user = $req->user;
+
     die error(404 => 'Missing route') unless $route;
 
     my $it = $route->{id} or die error(404 => 'No id');
     my $schema = $self->{+CONFIG}->schema;
-    my $field = $schema->resultset('JobField')->search({job_field_id => $it})->first or die error(404 => 'Invalid Run');
+    my $field = $schema->resultset('JobField')->search({job_field_id => $it})->first or die error(404 => 'Invalid Field');
+
+    if (my $act = $route->{action}) {
+        if ($act eq 'delete') {
+            $field->delete;
+        }
+    }
 
-    my $res = resp(200);
     $res->content_type('application/json');
     $res->raw_body($field);
     return $res;
@@ -37,7 +50,7 @@ __END__
 
 =head1 NAME
 
-Test2::Harness::UI::Controller::JobField
+Test2::Harness::UI::Controller::Run
 
 =head1 DESCRIPTION
 
