@@ -2,7 +2,7 @@ package Test2::Harness::UI::Controller::View;
 use strict;
 use warnings;
 
-our $VERSION = '0.000075';
+our $VERSION = '0.000076';
 
 use Data::GUID;
 use Text::Xslate(qw/mark_raw/);
@@ -31,7 +31,23 @@ sub handle {
 
     my $schema = $self->{+CONFIG}->schema;
 
+    my $id     = $route->{id};
     my $run_id = $route->{run_id};
+    my $project;
+
+    if ($id) {
+        my $p_rs = $schema->resultset('Project');
+        $project //= eval { $p_rs->search({project_id => $id})->first };
+        $project //= eval { $p_rs->search({name => $id})->first };
+
+        if ($project) {
+            $self->{+TITLE} .= ">" . $project->name;
+        }
+        else {
+            $run_id //= $id;
+        }
+    }
+
     if($run_id) {
         my $run = $schema->resultset('Run')->search({run_id => $run_id})->first or die error(404 => 'Invalid Run');
         $self->{+TITLE} .= ">" . $run->project->name;
@@ -48,7 +64,7 @@ sub handle {
     my $tx = Text::Xslate->new(path => [share_dir('templates')]);
 
     my $base_uri   = $req->base->as_string;
-    my $stream_uri = join '/' => $base_uri . 'stream', grep {length $_} $run_id, $job_uuid, $job_try;
+    my $stream_uri = join '/' => $base_uri . 'stream', grep {length $_} ($id // $run_id), $job_uuid, $job_try;
 
     my $content = $tx->render(
         'view.tx',
