@@ -126,11 +126,6 @@ CREATE TABLE permissions (
     UNIQUE(project_id, user_id)
 );
 
-CREATE TABLE coverage (
-    coverage_id     UUID            DEFAULT UUID_GENERATE_V4() PRIMARY KEY,
-    coverage        JSONB           DEFAULT NULL
-);
-
 CREATE TABLE runs (
     run_id          UUID            DEFAULT UUID_GENERATE_V4() PRIMARY KEY,
     run_ord         BIGSERIAL       NOT NULL,
@@ -154,17 +149,26 @@ CREATE TABLE runs (
     failed          INTEGER         DEFAULT NULL,
     retried         INTEGER         DEFAULT NULL,
     concurrency     INTEGER         DEFAULT NULL,
-    fields          JSONB           DEFAULT NULL,
     parameters      JSONB           DEFAULT NULL,
 
-    coverage_id     UUID            DEFAULT NULL REFERENCES coverage(coverage_id),
-
     UNIQUE(run_ord)
 );
 CREATE INDEX IF NOT EXISTS run_projects ON runs(project_id);
 CREATE INDEX IF NOT EXISTS run_status ON runs(status);
 CREATE INDEX IF NOT EXISTS run_user ON runs(user_id);
 
+CREATE TABLE run_fields (
+    run_field_id    UUID            NOT NULL PRIMARY KEY,
+    run_id          UUID            NOT NULL REFERENCES runs(run_id),
+    name            VARCHAR(255)    NOT NULL,
+    data            JSONB,
+    details         TEXT,
+    raw             TEXT,
+    link            TEXT,
+
+    UNIQUE(run_id, name)
+);
+
 CREATE TABLE jobs (
     job_key         UUID        NOT NULL PRIMARY KEY,
 
@@ -178,7 +182,6 @@ CREATE TABLE jobs (
     status          queue_status    NOT NULL DEFAULT 'pending',
 
     parameters      JSONB       DEFAULT NULL,
-    fields          JSONB       DEFAULT NULL,
 
     -- Summaries
     name            TEXT            DEFAULT NULL,
@@ -206,6 +209,18 @@ CREATE INDEX IF NOT EXISTS job_runs ON jobs(run_id);
 CREATE INDEX IF NOT EXISTS job_fail ON jobs(fail);
 CREATE INDEX IF NOT EXISTS job_file ON jobs(file);
 
+CREATE TABLE job_fields (
+    job_field_id    UUID            NOT NULL PRIMARY KEY,
+    job_key         UUID            NOT NULL REFERENCES jobs(job_key),
+    name            VARCHAR(255)    NOT NULL,
+    data            JSONB,
+    details         TEXT,
+    raw             TEXT,
+    link            TEXT,
+
+    UNIQUE(job_key, name)
+);
+
 CREATE TABLE events (
     event_id        UUID        NOT NULL PRIMARY KEY,
 
